

package src;

import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.OutputStream;
import java.io.PrintStream;
import javax.swing.*;

public class MainGUI {
	
	public static void main(final String[] args) {
		
		@SuppressWarnings("unused")
		Gui g = new Gui();
		
		//By creating this class, all elements of the Activity are created. 
		//The whole thing is started, because by creating the initial node, its start-flag is set to true which causes its
		//thread to start executing.
		
	}
}



class Gui {
	private JPanel controlButtonPanel; 
	private JPanel triggerButtonPanel;
	private mainFrame mFrame;
	
	public Gui(){
		this.mFrame = new mainFrame("Simulator for Example");
		
		controlButtonPanel = new JPanel(new GridLayout(1,2,10,10));
		triggerButtonPanel = new JPanel(new GridLayout(1,5,10,10));
		JPanel outputPanel = new JPanel(new GridLayout(1,1,0,0));
		
		//Next lines are required to redirect System.out to the GUI text area
		JTextArea outputTArea = new JTextArea();
		outputTArea.setLineWrap(true);
		outputTArea.setWrapStyleWord(true);
		TextAreaOutputStream tp = new TextAreaOutputStream(outputTArea);
		PrintStream out = new PrintStream(tp);
		System.setOut(out);
		System.setErr(out);
		JScrollPane pane = new JScrollPane(outputTArea);
		pane.setHorizontalScrollBarPolicy(JScrollPane.HORIZONTAL_SCROLLBAR_NEVER); 
		outputPanel.add(pane);
		
		Aktivitaet act = new Aktivitaet();	//Instantiate the System
			
		Container content = mFrame.getContentPane();		//Get the "main drawing area"
		content.setLayout(new BorderLayout());
		
		//SSAs without incoming ControlFlow can externally be triggered with Buttons: 
			JButton Send_EnableBtn = new JButton("Send_Enable");
		Send_EnableBtn.addActionListener(new Send_EnableBtnHandler(act.getRightActivity("Send_Enable")));
		triggerButtonPanel.add(Send_EnableBtn);		
		//Finally, add the controlling buttons to the top of the frame
		JButton btnStart = new JButton("Start Simulation");
		btnStart.addActionListener(new ButtonStartHandler(act.getRightActivity("ac0"), btnStart));
		controlButtonPanel.add(btnStart);

		JButton btnFreeze = new JButton("Freeze output");
		btnFreeze.addActionListener(new ButtonFreezeHandler(btnFreeze, out));
		controlButtonPanel.add(btnFreeze);
		
		JButton btnEnd = new JButton("End");
		btnEnd.addActionListener(new ButtonEndHandler(mFrame));
		controlButtonPanel.add(btnEnd);
		
		content.add(controlButtonPanel, BorderLayout.NORTH);	//Panel at top of Frame	
		content.add(outputPanel, BorderLayout.CENTER);
		content.add(triggerButtonPanel, BorderLayout.SOUTH);
		
		mFrame.setVisible(true);	//Enable the JFrame	and make it visible
	
	}
}

class mainFrame extends JFrame{
		
	private static final long serialVersionUID = 1L;
	mainFrame(String _name){
							
		super(_name);
		this.setSize(500, 800);	//size of the JFrame in Horizontal * Vertical Pixels
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);	//With this option, application will terminate when JFrame is closed
	}
}

/**
 * Class required to redirect System.out to the specified JTextArea
 */
class TextAreaOutputStream extends OutputStream {
	JTextArea taN;
	
	TextAreaOutputStream(JTextArea _taN){
		this.taN = _taN;
	}
	
    public void write(int b){
        try{
        	this.taN.append(String.valueOf((char) b));	
        	this.taN.setCaretPosition(taN.getLineEndOffset(taN.getLineCount() - 1));	//Necessary to scroll automatically
        } 
        catch (Exception e) {
        	e.printStackTrace();
        }
    }	    
}

//Handles the clock on the start button
class ButtonStartHandler implements ActionListener{
	ActivityNode startN;
	JButton startButton;
	
	public ButtonStartHandler(ActivityNode _a, JButton _startB) {
		startN = _a;
		startButton = _startB;
	}
	
	public void actionPerformed(ActionEvent e){
			startN.sema.unlock();			//Unlock the semaphore of the initial node upon button click
			startButton.setEnabled(false);	//The simulation can only be started once!
	}
}

//Handles the click on the End-Button
class ButtonEndHandler implements ActionListener{
	private JFrame jf;
	
	public ButtonEndHandler(JFrame _jf) {
		this.jf = _jf;
	}
	
	public void actionPerformed(ActionEvent e){
		this.jf.dispose();	//Close Mainframe
		System.exit(0);		//Kill JVM	
	}
}

class ButtonFreezeHandler implements ActionListener{

	private PrintStream out;
	private JButton btnFreeze;
	private boolean isFrozen = false;
		
	public ButtonFreezeHandler(JButton _btnFreeze, PrintStream _out) {
		out = _out;
		btnFreeze = _btnFreeze;
	}
	
	public void actionPerformed(ActionEvent e){
		if(isFrozen){
			//release
			btnFreeze.setText("Freeze output");
			System.setOut(out);
			System.setErr(out);
			System.out.println();
		}
		
		else {
			btnFreeze.setText("Release output");
			PrintStream temp = new PrintStream(new TextAreaOutputStream(new JTextArea()));	//Block output to textarea by redirection to nirvana
			System.setOut(temp);
			System.setErr(temp);
		}
		
		isFrozen = !isFrozen;
	}
}



class Send_EnableBtnHandler implements ActionListener{
	private ActivityNode nodeToControl;
	
	public Send_EnableBtnHandler(ActivityNode ac) {
		nodeToControl = ac;
	}
	
	public void actionPerformed(ActionEvent e) {
		nodeToControl.sema.unlock();	//To run an action, just unlock its semaphore. 
	}
}


