
package src;

import src.Display.*;
import src.Mul.*;
import src.Add.*;
import src.Generate2.*;
import src.Generate5.*;
import src.Generate7.*;


public abstract class Transition{
	protected ActivityNode targetActivity = null;
	protected ActivityNode sourceActivity = null;
	
	protected String name;
	
	public Transition(){}
	
	public Transition(String _name){
		name = _name;
	}
	
	public void setName(String _name){
		name = _name;
	}
	
	public String getName(){
		return name;
	}
	
	public void setSourceActivity (ActivityNode _n){
		this.sourceActivity = _n;
	}
	
	public void setTargetActivity(ActivityNode _n){
		this.targetActivity = _n;
	}
	
	public ActivityNode getSourceActivity(){
		return this.sourceActivity;
	}
	
	public ActivityNode getTargetActivity(){
		return this.targetActivity;
	}
	
	public void fireTransition(){
		targetActivity.executeAction(this);
	}
	
	public void fireTransition(Object o){
		targetActivity.executeAction(this);
	}
	
	//The following methods will be overwritten by the class ObjectFlow
	public void setSourceObject(ObjectNode _o){}

	public void setTargetObject(ObjectNode _o){}

	public ObjectNode getSourceObject(){
		return null;
	}

	public ObjectNode getTargetObject(){
		return null;
	}
	
}

//Base class for the object flows
class ObjectFlow extends Transition{
	protected ObjectNode sourceObject = null;		//Init the source and target object as null
	protected ObjectNode targetObject = null;
	protected InputPin targetPin = null;
	protected OutputPin sourcePin = null; 
	
	public ObjectFlow(){}
	
	public ObjectFlow(String _name){
		name = _name;
	}
	
	public void setName(String _name){
		name = _name;
	}
	
	public String getName(){
		return name;
	}
	
	//The following methods will be overwritten
	public void setTargetPin(InputPin p){}
	
	public InputPin getTargetPin(){
		return null;
	} 
	
	public void setSourcePin(OutputPin p){}
	
	public OutputPin getSourcePin(){
		return null;
	}	

	//Will be overwritten:
	public void fireTransition(){}
}



class ac18 extends ObjectFlow {
	private java.lang.Integer comObjectSource;
	private java.lang.Integer comObjectTarget;
	
	Display_in targetPin;
	
	public ac18(){
		name = "ac18"; 
	}
	
	public void setTargetPin(InputPin p){
		targetPin = (Display_in)p;
	}
	public InputPin getTargetPin(){
		return (InputPin)targetPin;
	}
	public void setSourcePin(OutputPin p){
		sourcePin = (Mul_out)p;
	}
	public OutputPin getSourcePin(){
		return (Mul_out)sourcePin;
	}
	
	public java.lang.Integer getComObjectTarget(){
		return comObjectTarget;
	}
	
	//Override from base class
	public void fireTransition(java.lang.Integer s){
		comObjectSource = s;
		comObjectTarget = comObjectSource;
		targetPin.execute(comObjectTarget);
	}
}

class ac19 extends ObjectFlow {
	private java.lang.Integer comObjectSource;
	private java.lang.Integer comObjectTarget;
	
	Mul_in1 targetPin;
	
	public ac19(){
		name = "ac19"; 
	}
	
	public void setTargetPin(InputPin p){
		targetPin = (Mul_in1)p;
	}
	public InputPin getTargetPin(){
		return (InputPin)targetPin;
	}
	public void setSourcePin(OutputPin p){
		sourcePin = (Generate2_out)p;
	}
	public OutputPin getSourcePin(){
		return (Generate2_out)sourcePin;
	}
	
	public java.lang.Integer getComObjectTarget(){
		return comObjectTarget;
	}
	
	//Override from base class
	public void fireTransition(java.lang.Integer s){
		comObjectSource = s;
		comObjectTarget = comObjectSource;
		targetPin.execute(comObjectTarget);
	}
}

class ac20 extends ObjectFlow {
	private java.lang.Integer comObjectSource;
	private java.lang.Integer comObjectTarget;
	
	Add_in1 targetPin;
	
	public ac20(){
		name = "ac20"; 
	}
	
	public void setTargetPin(InputPin p){
		targetPin = (Add_in1)p;
	}
	public InputPin getTargetPin(){
		return (InputPin)targetPin;
	}
	public void setSourcePin(OutputPin p){
		sourcePin = (Generate5_out)p;
	}
	public OutputPin getSourcePin(){
		return (Generate5_out)sourcePin;
	}
	
	public java.lang.Integer getComObjectTarget(){
		return comObjectTarget;
	}
	
	//Override from base class
	public void fireTransition(java.lang.Integer s){
		comObjectSource = s;
		comObjectTarget = comObjectSource;
		targetPin.execute(comObjectTarget);
	}
}

class ac21 extends ObjectFlow {
	private java.lang.Integer comObjectSource;
	private java.lang.Integer comObjectTarget;
	
	Add_in2 targetPin;
	
	public ac21(){
		name = "ac21"; 
	}
	
	public void setTargetPin(InputPin p){
		targetPin = (Add_in2)p;
	}
	public InputPin getTargetPin(){
		return (InputPin)targetPin;
	}
	public void setSourcePin(OutputPin p){
		sourcePin = (Generate7_out)p;
	}
	public OutputPin getSourcePin(){
		return (Generate7_out)sourcePin;
	}
	
	public java.lang.Integer getComObjectTarget(){
		return comObjectTarget;
	}
	
	//Override from base class
	public void fireTransition(java.lang.Integer s){
		comObjectSource = s;
		comObjectTarget = comObjectSource;
		targetPin.execute(comObjectTarget);
	}
}

class ac22 extends ObjectFlow {
	private java.lang.Integer comObjectSource;
	private java.lang.Integer comObjectTarget;
	
	Mul_in2 targetPin;
	
	public ac22(){
		name = "ac22"; 
	}
	
	public void setTargetPin(InputPin p){
		targetPin = (Mul_in2)p;
	}
	public InputPin getTargetPin(){
		return (InputPin)targetPin;
	}
	public void setSourcePin(OutputPin p){
		sourcePin = (Add_out)p;
	}
	public OutputPin getSourcePin(){
		return (Add_out)sourcePin;
	}
	
	public java.lang.Integer getComObjectTarget(){
		return comObjectTarget;
	}
	
	//Override from base class
	public void fireTransition(java.lang.Integer s){
		comObjectSource = s;
		comObjectTarget = comObjectSource;
		targetPin.execute(comObjectTarget);
	}
}
 


class ControlFlow extends Transition {
	public ControlFlow(){}
	
	public ControlFlow(String _name){
		name = _name;
	}
} 
